/**
 * Keyboard shortcuts for Project Ploughshares Transaction Management System
 */

/**
 * Show a modal with hotkey reference
 */
function showHotkeyReference() {
    // Create modal if it doesn't exist
    let modal = document.getElementById('hotkeyReferenceModal');
    
    if (!modal) {
        modal = document.createElement('div');
        modal.id = 'hotkeyReferenceModal';
        modal.className = 'modal fade';
        modal.tabIndex = '-1';
        modal.setAttribute('aria-labelledby', 'hotkeyReferenceModalLabel');
        modal.setAttribute('aria-hidden', 'true');
        
        modal.innerHTML = `
            <div class="modal-dialog modal-lg">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="hotkeyReferenceModalLabel">Keyboard Shortcuts</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                    </div>
                    <div class="modal-body">
                        <div class="row">
                            <div class="col-md-6">
                                <h6>Global Shortcuts</h6>
                                <table class="table table-sm">
                                    <tr>
                                        <td><kbd>H</kbd></td>
                                        <td>Show this help</td>
                                    </tr>
                                    <tr>
                                        <td><kbd>Alt</kbd> + <kbd>G</kbd></td>
                                        <td>Go to page</td>
                                    </tr>
                                </table>
                                
                                <h6>Transaction List</h6>
                                <table class="table table-sm">
                                    <tr>
                                        <td><kbd>N</kbd></td>
                                        <td>New transaction</td>
                                    </tr>
                                    <tr>
                                        <td><kbd>P</kbd></td>
                                        <td>Pending approval</td>
                                    </tr>
                                    <tr>
                                        <td><kbd>F</kbd></td>
                                        <td>Focus search</td>
                                    </tr>
                                    <tr>
                                        <td><kbd>R</kbd></td>
                                        <td>Refresh page</td>
                                    </tr>
                                </table>
                            </div>
                            <div class="col-md-6">
                                <h6>Transaction View</h6>
                                <table class="table table-sm">
                                    <tr>
                                        <td><kbd>E</kbd></td>
                                        <td>Edit transaction</td>
                                    </tr>
                                    <tr>
                                        <td><kbd>B</kbd></td>
                                        <td>Back to list</td>
                                    </tr>
                                    <tr>
                                        <td><kbd>←</kbd></td>
                                        <td>Previous transaction</td>
                                    </tr>
                                    <tr>
                                        <td><kbd>→</kbd></td>
                                        <td>Next transaction</td>
                                    </tr>
                                    <tr>
                                        <td><kbd>A</kbd></td>
                                        <td>Approve transaction</td>
                                    </tr>
                                </table>
                                
                                <h6>Pending Approval</h6>
                                <table class="table table-sm">
                                    <tr>
                                        <td><kbd>B</kbd></td>
                                        <td>Back to list</td>
                                    </tr>
                                    <tr>
                                        <td><kbd>R</kbd></td>
                                        <td>Refresh page</td>
                                    </tr>
                                    <tr>
                                        <td><kbd>1</kbd>-<kbd>9</kbd></td>
                                        <td>View transaction #1-9</td>
                                    </tr>
                                </table>
                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    </div>
                </div>
            </div>
        `;
        
        document.body.appendChild(modal);
    }
    
    // Show the modal
    const bsModal = new bootstrap.Modal(modal);
    bsModal.show();
}

/**
 * Show a modal for quick navigation
 */
function showGoToModal() {
    // Create modal if it doesn't exist
    let modal = document.getElementById('goToModal');
    
    if (!modal) {
        modal = document.createElement('div');
        modal.id = 'goToModal';
        modal.className = 'modal fade';
        modal.tabIndex = '-1';
        modal.setAttribute('aria-labelledby', 'goToModalLabel');
        modal.setAttribute('aria-hidden', 'true');
        
        modal.innerHTML = `
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="goToModalLabel">Go To</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                    </div>
                    <div class="modal-body">
                        <div class="list-group">
                            <a href="/" class="list-group-item list-group-item-action d-flex justify-content-between align-items-center">
                                Home
                                <span class="badge bg-primary">H</span>
                            </a>
                            <a href="/transaction/add" class="list-group-item list-group-item-action d-flex justify-content-between align-items-center">
                                New Transaction
                                <span class="badge bg-primary">N</span>
                            </a>
                            <a href="/pending-approval" class="list-group-item list-group-item-action d-flex justify-content-between align-items-center">
                                Pending Approval
                                <span class="badge bg-primary">P</span>
                            </a>
                            <a href="/api-docs" class="list-group-item list-group-item-action d-flex justify-content-between align-items-center">
                                API Documentation
                                <span class="badge bg-primary">D</span>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        `;
        
        document.body.appendChild(modal);
    }
    
    // Show the modal
    const bsModal = new bootstrap.Modal(modal);
    bsModal.show();
}

// Make functions available globally
window.showHotkeyReference = showHotkeyReference;
window.showGoToModal = showGoToModal;

document.addEventListener('DOMContentLoaded', function() {
    // Initialize hotkeys
    initHotkeys();

    // Add hotkey tooltips to elements
    addHotkeyTooltips();
});

/**
 * Initialize keyboard shortcuts
 */
function initHotkeys() {
    document.addEventListener('keydown', function(event) {
        // Skip if user is typing in an input field, textarea or has a modal open
        if (isUserTyping() || isModalOpen()) {
            return;
        }

        // Get the current page based on URL
        const currentPath = window.location.pathname;
        
        // Global shortcuts (available on all pages)
        switch (event.key) {
            case 'h': // Help - Show hotkey reference
                event.preventDefault();
                showHotkeyReference();
                break;
            case 'g': // Go to
                if (event.altKey) {
                    event.preventDefault();
                    showGoToModal();
                }
                break;
        }

        // Page-specific shortcuts
        if (currentPath === '/' || currentPath === '/index.html') {
            // Transaction list page
            handleTransactionListHotkeys(event);
        } else if (currentPath.startsWith('/transaction/') && !currentPath.includes('/edit')) {
            // Transaction view page
            handleTransactionViewHotkeys(event);
        } else if (currentPath === '/pending-approval') {
            // Pending approval page
            handlePendingApprovalHotkeys(event);
        }
    });
}

/**
 * Handle hotkeys for the transaction list page
 */
function handleTransactionListHotkeys(event) {
    switch (event.key) {
        case 'n': // New transaction
            event.preventDefault();
            window.location.href = '/transaction/add';
            break;
        case 'p': // Pending approval
            event.preventDefault();
            window.location.href = '/pending-approval';
            break;
        case 'f': // Focus search
            event.preventDefault();
            const searchInput = document.getElementById('searchInput');
            if (searchInput) {
                searchInput.focus();
            }
            break;
        case 'r': // Refresh
            event.preventDefault();
            window.location.reload();
            break;
    }
}

/**
 * Handle hotkeys for the transaction view page
 */
function handleTransactionViewHotkeys(event) {
    switch (event.key) {
        case 'e': // Edit
            event.preventDefault();
            const editBtn = document.querySelector('a[href^="/transaction/"][href$="/edit"]');
            if (editBtn) {
                editBtn.click();
            }
            break;
        case 'b': // Back to list
            event.preventDefault();
            window.location.href = '/';
            break;
        case 'ArrowLeft': // Previous transaction
            event.preventDefault();
            const prevBtn = document.querySelector('a[aria-label="Previous transaction"]');
            if (prevBtn && !prevBtn.classList.contains('disabled') && !prevBtn.hasAttribute('disabled')) {
                prevBtn.click();
            }
            break;
        case 'ArrowRight': // Next transaction
            event.preventDefault();
            const nextBtn = document.querySelector('a[aria-label="Next transaction"]');
            if (nextBtn && !nextBtn.classList.contains('disabled') && !nextBtn.hasAttribute('disabled')) {
                nextBtn.click();
            }
            break;
        case 'a': // Approve
            event.preventDefault();
            const approveBtn = document.querySelector('button[data-bs-target="#approveModal"]');
            if (approveBtn) {
                approveBtn.click();
            }
            break;
    }
}

/**
 * Handle hotkeys for the pending approval page
 */
function handlePendingApprovalHotkeys(event) {
    switch (event.key) {
        case 'b': // Back to list
            event.preventDefault();
            window.location.href = '/';
            break;
        case 'r': // Refresh
            event.preventDefault();
            window.location.reload();
            break;
        // Number keys 1-9 to quickly view transactions
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':
            event.preventDefault();
            const index = parseInt(event.key) - 1;
            const viewButtons = document.querySelectorAll('a[aria-label^="View transaction"]');
            if (viewButtons.length > index) {
                viewButtons[index].click();
            }
            break;
    }
}

/**
 * Check if user is currently typing in an input field
 */
function isUserTyping() {
    const activeElement = document.activeElement;
    return activeElement.tagName === 'INPUT' || 
           activeElement.tagName === 'TEXTAREA' || 
           activeElement.isContentEditable;
}

/**
 * Check if a modal is currently open
 */
function isModalOpen() {
    return document.querySelector('.modal.show') !== null;
}

/**
 * Add hotkey tooltips to elements
 */
function addHotkeyTooltips() {
    // Get the current page based on URL
    const currentPath = window.location.pathname;
    
    // Page-specific tooltips
    if (currentPath === '/' || currentPath === '/index.html') {
        // Transaction list page
        const newTransactionBtn = document.querySelector('a[href="/transaction/add"]');
        if (newTransactionBtn) {
            newTransactionBtn.setAttribute('title', 'New Transaction (N)');
        }
        
        const pendingApprovalLink = document.querySelector('a[href="/pending-approval"]');
        if (pendingApprovalLink) {
            pendingApprovalLink.setAttribute('title', 'Pending Approval (P)');
        }
        
    } else if (currentPath.startsWith('/transaction/') && !currentPath.includes('/edit')) {
        // Transaction view page
        const editBtn = document.querySelector('a[href^="/transaction/"][href$="/edit"]');
        if (editBtn) {
            editBtn.setAttribute('title', 'Edit Transaction (E)');
        }
        
        const backBtn = document.querySelector('a[href="/"]');
        if (backBtn) {
            backBtn.setAttribute('title', 'Back to List (B)');
        }
        
        const prevBtn = document.querySelector('a[aria-label="Previous transaction"]');
        if (prevBtn) {
            prevBtn.setAttribute('title', 'Previous Transaction (←)');
        }
        
        const nextBtn = document.querySelector('a[aria-label="Next transaction"]');
        if (nextBtn) {
            nextBtn.setAttribute('title', 'Next Transaction (→)');
        }
        
        const approveBtn = document.querySelector('button[data-bs-target="#approveModal"]');
        if (approveBtn) {
            approveBtn.setAttribute('title', 'Approve Transaction (A)');
        }
    } else if (currentPath === '/pending-approval') {
        // Pending approval page
        const backBtn = document.querySelector('a[href="/"]');
        if (backBtn) {
            backBtn.setAttribute('title', 'Back to List (B)');
        }
        
        // Add numbers to view buttons
        const viewButtons = document.querySelectorAll('a[aria-label^="View transaction"]');
        viewButtons.forEach((btn, index) => {
            if (index < 9) {
                btn.setAttribute('title', `View Transaction (${index + 1})`);
            }
        });
    }
} 